// pages/order/order.js
const app = getApp()
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')
const envInfo = require('../../config/index').envInfo
const ORDER_STATUS_TEXT = {
  N: "待付款",
  P: "待发货",
  D: "待收货",
  R: "已完成",
  C: "已关闭",
  PR : "退货中",
  RE : "退货完成",
};

const  STATUS_CLASS = {
  N: "package-status-color-N",
  P: "package-status-color-P",
  D: "package-status-color-D",
  R: "package-status-color-R",
  C: "package-status-color-C",
  PR : "package-status-color-C",
  RE : "package-status-color-C",
}

wxService.page({
  /**
   * 页面的初始数据
   */
  data: {
    showApplyRefundModal: false,
    // 订单状态(C:取消;N:新建,P:已支付;D:已发货;R:已收货)
    swiperItem: [
      {
        type: '1',
        status: '',
        name: '全部',
        hasTips : false
      },
      {
        type: '2',
        status: 'N',
        name: '待付款', // 新建
        hasTips: false
      },
      {
        type: '3',
        status: 'P',
        name: '待发货',
        hasTips: false
      },
      {
        type: '4',
        status: 'D',
        name: '待收货',
        hasTips: false
      },
      {
        type: '5',
        status: 'RF',
        name: '退款/售后',
        hasTips: false
      }
    ],
    currentIndex: 1,
    pageNo: 1,
    pageSize: 10,
    noMoreFlag: false,
    orderList: null,
    totalPages: 0,
    subImgs: [],
    status: '',  // 订单状态(C:取消;N:新建,P:已支付;D:已发货;R:已收货)
    no_data: true,
    currentTradeId: '',
    refundId : ''
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu()
  },

  //复制
  onTapCopy(e){
    wx.setClipboardData({
      //准备复制的数据
      data: e.currentTarget.dataset.no,
      success: function (res) {
        wx.showToast({
          title: '复制成功',
          icon: 'none'
        });
      }
    });
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    const { currentIndex } = this.data;

    this.handleOrderStatus(this.options.orderStatus)
    if (currentIndex == 5) {
      this.getRefundList(this.data.pageNo, this.data.pageSize)
    } else {
      this.setData({
        pageNo: 1,
        pageSize: 10
      }, () => {
        this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
      })
    }
  },
  //处理订单状态
  handleOrderStatus(orderStatus){
    if(orderStatus){
      this.data.swiperItem.forEach(item => {
        if (item.status == orderStatus){
          this.data.currentIndex = item.type;
          this.data.status = orderStatus;
        }
      });

      this.setData({
        currentIndex : this.data.currentIndex
      });
    }
  },
  // 确认收货
  handelConfirmReceipt(e) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })

    let id = e.currentTarget.dataset.id;
    let packageInfo = e.currentTarget.dataset.package;
    let parcelId = packageInfo.id;

    if (parcelId){
      this.packageConfirmReceive(id,parcelId);
    }
    else{
      this.oldVersionConfirmReceive(id);
    }
  },
  //包裹的确认收货
  packageConfirmReceive(findId, parcelId){
    wxService.post(`/sale/trade/buyer/parcelConfirm?findId=${findId}&parcelId=${parcelId}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        }
      }
    })
  },
  //兼容以前老数据进行确认收货
  oldVersionConfirmReceive(id){
    wxService.post(`/sale/trade/buyer/confirm/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        }
      }
    })
  },

  // 取消订单
  handelCancelOrder(e) { 
    let _this = this;
    wx.showModal({
      title: '订单取消提示',
      content: '确认取消此订单？',
      showCancel: true,
      cancelText: '再想想',
      confirmText: '取消订单',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          //跳去开卡
          const { id } = e.currentTarget.dataset
          wx.showLoading({
            title: '订单取消中..',
            mask: true
          });

          wxService.post(`/sale/trade/buyer/cancel/${id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `取消成功!`,
                  icon: 'none'
                })
                setTimeout(() => {
                  _this.initOrderList(_this.data.pageNo, _this.data.pageSize, _this.data.status)
                }, 200)
              } else {
                wx.showToast({
                  title: `取消失败!`,
                  icon: 'none'
                })
              }
            }
          })
        }
      }
    });
  },
  // 申请退款
  handelRequestRefund(e) {
    let orderId = e.currentTarget.dataset.id;
    let packageInfo = e.currentTarget.dataset.package;

    let detail = {
      id : orderId,
      skuVOList: packageInfo.sendOutList, 
    }

    let copyOrderInfo = JSON.parse(JSON.stringify(detail));
    //过滤掉已经退货完的商品
    copyOrderInfo.skuVOList = copyOrderInfo.skuVOList.filter(item => item.canRefundNum > 0);
    //更新可退货数量
    copyOrderInfo.skuVOList.forEach(item => {
      item.totalCount = item.count;
      item.count = item.canRefundNum;
    });

    let params = JSON.stringify(copyOrderInfo);
    // 退款申请
    wxService.router(`/pages/refund/refund`).search({params})
  },
  // 删除订单
  handelDelOrder(e) {
    let _this = this; 
    //先判断整个订单的所有包裹是否都已经

    wx.showModal({
      title: '订单删除提示',
      content: '删除订单将删除订单中所有的包裹，请谨慎操作？',
      showCancel: true,
      cancelText: '取消',
      confirmText: '全部删除',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          const { id } = e.currentTarget.dataset
          wx.showLoading({
            title: '订单删除中..',
            mask: true
          })
          wxService.post(`/sale/trade/buyer/delete/${id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `删除成功!`,
                  icon: 'none'
                })
                setTimeout(() => {
                  _this.initOrderList(_this.data.pageNo, _this.data.pageSize, _this.data.status)
                }, 200)
              }
            } else {
              wx.showToast({
                title: `删除失败!`,
                icon: 'none'
              })
            }
          });
        }
      }
    });
  },
  // 立即支付
  handelToPay(e) {
    let _this=  this;
    const { id, merged } = e.currentTarget.dataset
    let url = merged ? `/sale/payment/merged/buyer/wxprepay/${id}` : `/sale/trade/buyer/wxprepay/${id}`
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wxService.post(`${url}`).then(res => {
    // wxService.post(`/sale/trade/buyer/wxprepay/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let amount = data.amount || 0
          wx.hideLoading()
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // 支付成功页面
              wx.showToast({
                title: '支付成功',
              });
              
              _this.initOrderList(_this.data.pageNo, _this.data.pageSize, _this.data.status)
            },
            fail(res) {
              wx.hideLoading()
              wx.showToast({
                title: '支付失败',
              });
            }
          }, data))

        }
      }
    })
  },
  // 查看物流
  checkLogistics(e) {
    let { detail } = e.currentTarget.dataset;
    let { id } = e.currentTarget.dataset;
    let item = e.currentTarget.dataset.item;
    let obj = {};
    if (detail.code){
      obj = {
        id: id,
        logistic: {
          supplierName: detail.supplierName,
          code: detail.code,
          supplierCode: detail.supplierCode,
        },
        status: detail.status,
      }
    }
    else{
      obj = {
        id: id,
        logistic: {
          supplierName: item.logistic.supplierName,
          code: item.logistic.code,
          supplierCode: item.logistic.supplierCode,
        },
        status: detail.status,
      }
    }

    let params = JSON.stringify(obj);
    // // 退款申请
    wxService.router(`/pages/logistics/logistics`).search({params});
  },
  // 查看详情
  handelCheckRfDetail(e) {
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/orderDetail/orderDetail?id=${id}`)
  },
  // 订单详情
  handelDetail(e) {
    // const {detail} = e.currentTarget.dataset
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/orderDetail/orderDetail?id=${id}`)
  },
  // 退单详情 
  handelDetailRf(e) {
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/refundDetail/refundDetail?id=${id}`)
  },
  // 取消退款
  handelCancelRefund(e) {
    const { id } = e.currentTarget.dataset
    this.handelRevokeRefund(id)
  },

  handelRevokeRefund(id) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = { id }
    wxService.post(`/sale/refund/buyer/cancel?id=${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: '取消退款成功',
          });
          setTimeout(() => {
            this.getRefundList(this.data.pageNo, this.data.pageSize);
          }, 200)
        }
      }
    })
  },

  //点击切换tab
  switchTab(e) {
    const { type, status } = e.currentTarget.dataset
    const { currentIndex } = this.data
    if (currentIndex == type) return false
    this.setData({
      currentIndex: type,
      pageNo: 1,
      orderList: [],
      status: '',
      no_data: true
    }, () => {
      if (type == 5 && status == 'RF') {
        this.getRefundList(this.data.pageNo, this.data.pageSize)
      } else {
        this.setData({
          status: status
        }, () => {
          this.initOrderList(this.data.pageNo, this.data.pageSize, status)
        })

      }
    })
  },
  //获取订单列表
  initOrderList(pageNo, pageSize, status) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })

    const params = { status: status,orderType:1 }
    wxService.post(`/sale/trade/buyer/history?pageNum=${pageNo}&pageSize=${pageSize}`, params).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading();
          let orderList = data ? data : [];
          // 处理包裹数据信息
          orderList.forEach(item => {
            item.statusText = ORDER_STATUS_TEXT[item.status];
            let parcelList = item.parcelList ? item.parcelList : [];
            let skuVOList = item.skuVOList ? item.skuVOList : [];
            skuVOList.forEach(sku => {
              sku.refundCount = sku.refundCount ? sku.refundCount : 0;
              sku.canRefundNum = (sku.count - sku.refundCount) >= 0 ? (sku.count - sku.refundCount) : 0;
            });
            if(parcelList.length == 0){
              if(item.status == 'N' || item.status == 'C'){
                parcelList = [{
                    code : '',
                    supplierCode : '',
                    supplierName : '',
                    status : item.status,
                    statusText : item.statusText,
                    statusClass : STATUS_CLASS[item.status],
                    orderCanRefund : false,
                    sendOutList : item.skuVOList
                }];
              }
              else{
                parcelList = [{
                    code : '',
                    supplierCode : '',
                    supplierName : '',
                    status : item.status,
                    statusText : item.statusText,
                    statusClass : STATUS_CLASS[item.status],
                    orderCanRefund : true,
                    sendOutList : item.skuVOList
                }];
              }
            }
            else{
              parcelList.forEach(p => {
                p.deliverTime = p.deliverTime ? p.deliverTime : '';
                //计算一下包裹能不能退货
                let deliverTime = p.deliverTime ? p.deliverTime  : null;
                p.statusText = ORDER_STATUS_TEXT[p.status];
                p.statusClass = STATUS_CLASS[p.status];
                if(deliverTime){
                  let diffObj = utils.getDateDiff(deliverTime);
                  if (diffObj.days <= this.data.canRefundDaysAfterDelivery){
                    p.orderCanRefund = true;
                  }
                  else{
                    p.orderCanRefund = false;
                  }
                }
                else{
                  p.orderCanRefund = true;
                }
  
                //找商品填充
                let sendOutList = [];
                p.sendOutList.forEach(s => {
                    let filter = item.skuVOList.filter(f => f.skuId == s.skuId);
                    if(filter.length > 0){
                        sendOutList.push(filter[0]);
                    }
                });
  
                p.sendOutList = sendOutList;
              });
            }
            //这里需要处理移除非选中tab状态下的包裹（待收货中包含了待收货和已完成状态的包裹）
            if(!status){
              item.parcelList = parcelList;
            }
            else if(status != 'D'){
              parcelList = parcelList.filter(pa => pa.status == status);
              item.parcelList = parcelList;
            }
            else{
              parcelList = parcelList.filter(pa => pa.status != 'P');
              item.parcelList = parcelList;
            }
          });

          if(this.data.pageNo == 1){
            this.data.orderList = orderList;
          }
          else{
            this.data.orderList = [...this.data.orderList,...orderList];
          }

          this.setData({
            orderList: this.data.pageNo == 1 ? [...data] : [...this.data.orderList, ...data],
            noMoreFlag: data.length < pageSize ? true : false,
            no_data: this.data.orderList.length ? true : false
          });
        }
      }
    })
  },
  // 退款列表 /refund/buyer/history  订单状态(C:取消;N:新建,A:已审核;R:退货已发R货;D:退货已收货)
  getRefundList(pageNo, pageSize) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = {}
    wxService.post(`/sale/refund/buyer/history?pageNum=${pageNo}&pageSize=${pageSize}`, params).then(res => {
      if (res) {
        let { result, data } = res.data
        if (result == 0) {
          wx.hideLoading();
          data = data ? data : [];
          data.forEach(item => {
            let refundCount = 0;
            let skuList = item.skuList, tradeVOSku = item.tradeVO.skuVOList;
            skuList.forEach(item => {
              let filter = tradeVOSku.filter(c => c.skuId == item.skuId);
              refundCount = refundCount + item.count;
              if (filter.length > 0) {
                item.skuImgUrl = filter[0].skuImgUrl;
                item.productName = filter[0].productName;
                item.skuSpec = filter[0].skuSpec;
                item.price = filter[0].price;
                item.count = filter[0].count;
              }
            });

            item.refundCount = refundCount;
          });

          //获取总的退款商品数量
          

          this.setData({
            orderList: this.data.pageNo == 1 ? [...data] : [...this.data.orderList, ...data],
            noMoreFlag: data.length < pageSize ? true : false
          }, () => {
            this.setData({
              no_data: this.data.orderList.length ? true : false,
            });
          })
        }
      }
    })
  },
  
  //发货之后回调
  onDeliveryOk(){
    this.getRefundList(1,5);
  },
  //填写物流信息
  tapWriteLogis(e) {
    let refundId = e.currentTarget.dataset.id;
    this.setData({
      showApplyRefundModal: true,
      refundId: refundId
    })
  },
  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    this.data.pageNo = 1;
    if (this.data.currentIndex == 5){
      this.getRefundList(this.data.pageNo, this.data.pageSize)
    }
    else{
      this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
    }

    setTimeout(() => {
      wx.stopPullDownRefresh();
    },500);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    this.setData({
      pageNo: this.data.pageNo + 1,
    }, () => {
      this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
    })
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  }
})