// pages/orderDetail/orderDetail.js
const app = getApp()
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')
const envInfo = require('../../config/index').envInfo
const orderTopBg = 'https://img3.bigaka.com/prd/3001/202003/20200309/3001a46ba5bf-235d-428b-b7bb-befcf37ff89b.jpg';
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    detail: null,
    id: '',
    localNowTime: 0,
    hour: '00',
    min: '00',
    sec: '00',
    ms:  '0',
    mergedAmount: 0,
    totalGoodsPrice : 0,
    canApplyRefund : true,
    orderTopBg : orderTopBg,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.data.id = options.id;
    wx.hideShareMenu()
  },
  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    const { id } = this.options;
    if(id) {
      this.setData({
        id
      },()=>{
        this.getOrderDetail(id)
      })
    }
  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    this.getOrderDetail(this.data.id);
    setTimeout(() => {
      wx.stopPullDownRefresh();
    }, 500);
  },

  //获取订单详情
  getOrderDetail(id){
    wx.showLoading({
      title: '加载中',
      mask: true
    });

    wxService.get(`/sale/trade/seller/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading();
          //处理总数
          let skuVOList = data.skuVOList ? data.skuVOList : [];
          let sum = 0 ; 
          skuVOList.forEach(item => {
            item.refundCount = item.refundCount ? item.refundCount : 0;
            item.canRefundNum = (item.count - item.refundCount) >= 0 ? (item.count - item.refundCount) : 0;
            sum = sum + item.price * item.count;
          });
          
          //处理收货地址
          if (data.logistic){
            let receiverInfoArr = data.logistic.receiverInfo.split(',').reverse().filter(item => item);
            data.logistic.receiverName = receiverInfoArr[1];
            data.logistic.receiverMobile = receiverInfoArr[0];
            data.logistic.receiverAddress = receiverInfoArr[2] + receiverInfoArr[3];
          }
          else{
            data.logistic = null;
          }

          //处理能不能退款
          let canApplyRefund = true;
          let filter = skuVOList.filter(c => c.canRefundNum > 0);
          if (filter.length > 0){
            canApplyRefund = true;
          }
          else{
            canApplyRefund = false;
          }

          if(data.status == 'N' || data.status == 'C'){
            const { localNowTime} = this.data
            data.localNowTime = localNowTime ? localNowTime : new Date().getTime();
            data.createOrderTime = new Date(data.createTime.replace(/-/g,'/')).getTime() || [];
            data.countDownOrderTime = 7200000; // 2时(h)=7200000毫秒(ms)
            // 订单倒计时  超多两小时 刷新当前页
            data.orderCanRefund = true;
         
            data.skuVOList.forEach(item => {
              item.status = data.status;
            });

            data.parcelList = [{
              code : '',
              supplierCode : '',
              supplierName : '',
              status : data.status,
              sendOutList : data.skuVOList,
            }];

            this.data.totalGoodsPrice = parseFloat(sum).toFixed(2);
            this.setData({
              detail: data,
              totalGoodsPrice: this.data.totalGoodsPrice,
              mergedAmount: data.mergedAmount || 0,
              canApplyRefund: canApplyRefund
            }, ()=>{
              this.initCountDown(data.countDownOrderTime, data.createOrderTime, data.localNowTime)
            });
          }
          else{
            let parcelList = data.parcelList ? data.parcelList : [];
            if(parcelList.length == 0){
              parcelList = [{
                code : '--',
                supplierCode : '--',
                supplierName : '--',
                status : data.status,
                orderCanRefund : true,
                deliverTime : '--',
                sendOutList : data.skuVOList,
              }]

              data.parcelList = parcelList;
            }
            else{
              parcelList.forEach(item => {
                item.code = item.code ? item.code : '--';
                item.supplierCode = item.supplierCode ? item.supplierCode : '--';
                item.supplierName = item.supplierName ? item.supplierName : '--';
                item.status = item.status;
                item.deliverTime = item.deliverTime ? item.deliverTime : '';
                //计算一下包裹能不能退货
                let deliverTime = item.deliverTime ? item.deliverTime  : null;
                if(deliverTime){
                  let diffObj = utils.getDateDiff(deliverTime);
                  if (diffObj.days <= this.data.canRefundDaysAfterDelivery){
                    item.orderCanRefund = true;
                  }
                  else{
                    item.orderCanRefund = false;
                  }
                }
                else{
                  item.orderCanRefund = true;
                }
  
                //找商品填充
                let sendOutList = [];
                item.sendOutList.forEach(s => {
                    let filter = data.skuVOList.filter(f => f.skuId == s.skuId);
                    if(filter.length > 0){
                        sendOutList.push(filter[0]);
                    }
                });
  
                item.sendOutList = sendOutList;
              });
            }

            this.data.totalGoodsPrice = parseFloat(sum).toFixed(2);
            this.setData({
              detail: data,
              totalGoodsPrice: this.data.totalGoodsPrice,
              mergedAmount: data.mergedAmount || 0,
              canApplyRefund: canApplyRefund
            });
          }
        }
      }
    })
  },
  
  initCountDown(countDownOrderTime,startTime,localTime) {
    // 毫秒差 本地时间 - 创建时间
    let countTimeSpan = localTime - startTime
  
    let countDownTimer = setInterval(() => {
      countDownOrderTime -= 1000
      let result = this.getCountDown(countTimeSpan, countDownOrderTime);
      if (result.isOver) {
        clearInterval(countDownTimer);
      } else {
        this.setData({
          hour: result.hour,
          min: result.min,
          sec: result.sec,
          ms: result.ms,
        })
      }
    }, 1000);
  },
  getCountDown(time, countDownOrderTime) {
     // 判断是否为时间戳
     let distancetime = time < countDownOrderTime ? countDownOrderTime - time : 0;
 
    // 毫秒差 本地时间 - 创建时间   7200000毫秒(ms)
     let result = {
       hour: '00',
       min: '00',
       sec: '00',
       ms: '00',
       isOver: true,
     };
     if (distancetime) {
      // 如果大于7200000.说明尚未到达截止时间
       result.ms = Math.floor((distancetime % 1000) / 100);
       result.sec = Math.floor((distancetime / 1000) % 60);
       result.min = Math.floor((distancetime / 1000 / 60) % 60);
       result.hour = Math.floor((distancetime / 1000 / 60 / 60) % 24);
       result.isOver = false;
 
       if (result.ms < 10) result.ms = result.ms;
       if (result.sec < 10) result.sec = '0' + result.sec;
       if (result.min < 10) result.min = '0' + result.min;
       if (result.hour < 10) result.hour = '0' + result.hour;
     } else {
       const {detail, id} = this.data
        if (!this.getDetailLimitCount) {
          this.getDetailLimitCount = 1
        } else {
          this.getDetailLimitCount++
        }
        if (this.getDetailLimitCount <= 1 && detail.status == 'N') {
          this.getOrderDetail(id)
        } 
     }

     return result;
  },
  // 删除订单
  handelDelOrder(e) {
    let _this = this;
    wx.showModal({
      title: '订单删除提示',
      content: '确认删除此订单？',
      showCancel: true,
      cancelText: '取消',
      confirmText: '删除',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          const { id } = e.currentTarget.dataset
          wx.showLoading({
            title: '订单删除中..',
            mask: true
          })
          wxService.post(`/sale/trade/buyer/delete/${id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `删除成功!`,
                });
                setTimeout(() => {
                  wx.navigateBack({
                    delta : 1
                  });
                }, 500);
              } else {
                wx.showToast({
                  title: `删除失败!`,
                  icon: 'none'
                })
              }
            }
          });
        }
      }
    });
    
  },
  // 立即支付
  handelToPay(e) { 
    const { id } = e.currentTarget.dataset
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    
    const { mergedAmount } = this.data
    let url = mergedAmount ? `/sale/payment/merged/buyer/wxprepay/${id}` : `/sale/trade/buyer/wxprepay/${id}`
    wxService.post(`${url}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let amount = data.amount || 0
          wx.hideLoading()
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // 支付成功页面
              // wxService.router(`/subPackage/page/pages/paymentStatus/paymentStatus?status=S&amount=${amount}`)
              wx.showToast({
                title: '支付成功',
              });

              this.getOrderDetail(this.data.id);
            },
            fail(res) {
              wx.hideLoading()
              wx.showToast({
                title: '支付失败',
              });
            }
          }, data))

        }
      }
    })
  },
  // 取消订单
  handelCancelOrder(e) { 
    let _this = this;
    wx.showModal({
      title: '订单取消提示',
      content: '确认取消此订单？',
      showCancel: true,
      cancelText: '再想想',
      confirmText: '取消订单',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          //跳去开卡
          const { id } = e.currentTarget.dataset
          wx.showLoading({
            title: '订单取消中..',
            mask: true
          });

          wxService.post(`/sale/trade/buyer/cancel/${id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `取消成功!`,
                  icon: 'none'
                })
                setTimeout(() => {
                  _this.getOrderDetail(_this.data.id);
                }, 200)
              } else {
                wx.showToast({
                  title: `取消失败!`,
                  icon: 'none'
                })
              }
            }
          })
        }
      }
    });
  },
  // 查看物流
  checkLogistics(e) {
    let { detail } = e.currentTarget.dataset;
    let obj = {
      id: this.data.id,
      logistic: {
        supplierName : detail.supplierName,
        code : detail.code,
        supplierCode : detail.supplierCode,
      },
      status: detail.status,
    }

    let params = JSON.stringify(obj);
    // // 退款申请
    wxService.router(`/pages/logistics/logistics`).search({params});
  },
  // 申请退款
  handelRequestRefund(e) {
    console.log(e)
    let orderId = e.currentTarget.dataset.id;
    let packageInfo = e.currentTarget.dataset.package;

    let detail = {
      id : orderId,
      skuVOList :packageInfo.sendOutList, 
    }

    let copyOrderInfo = JSON.parse(JSON.stringify(detail));
    //过滤掉已经退货完的商品
    copyOrderInfo.skuVOList = copyOrderInfo.skuVOList.filter(item => item.canRefundNum > 0);
    //更新可退货数量
    copyOrderInfo.skuVOList.forEach(item => {
      item.totalCount = item.count;
      item.count = item.canRefundNum;
    });

    let params = JSON.stringify(copyOrderInfo);
    // 退款申请
    wxService.router(`/pages/refund/refund`).search({params})
   },
  // 确认收货
  handelConfirmReceipt(e) { 
    let id = e.currentTarget.dataset.id;
    let packageInfo =  e.currentTarget.dataset.package;
    let parcelId = packageInfo.id;

    wx.showLoading({
      title: '加载中',
      mask: true
    });

    //兼容老数据
    if(parcelId){
      this.packageConfirmReceive(id,parcelId);
    }
    else{
      this.oldVersionConfirmReceive(id);
    }
  },
  //包裹的确认收货
  packageConfirmReceive(findId, parcelId){
    wxService.post(`/sale/trade/buyer/parcelConfirm?findId=${findId}&parcelId=${parcelId}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.getOrderDetail(this.data.id);
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
        }
      }
    })
  },
  //兼容以前老数据进行确认收货
  oldVersionConfirmReceive(id){
    wxService.post(`/sale/trade/buyer/confirm/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.getOrderDetail(this.data.id);
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
        }
      }
    })
  },
  copy(e) {
    wx.setClipboardData({
      //准备复制的数据
      data: e.currentTarget.dataset.content,
      success: function (res) {
        wx.showToast({
          title: '复制成功',
          icon: 'none'
        });
      }
    });
  },
})