// shoppingGuid/page/pages/achievement/achievement.js
const wxService = require('../../../../utils/wxService');
const app = getApp();
// import wxCharts from '../../../../charts/wxcharts-min.js'
const wxCharts = require('../../../../charts/wxcharts-min.js')

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    filterBar: [
      { name: '本月', isActive: true, index: 1 }, 
      { name: '上月', isActive: false, index: 2 }, 
      { name: '3个月', isActive: false, index: 3 }
    ],
    current : 1,
    currentOrderData : {},
    avator: 'https://img3.bigaka.com/prd/3001/202003/20200331/3001e669048a-b2e6-452f-9ae5-f659a56be66e.png',
    info : {},
    achievement : {},
    memberPreview : {
      rank : 0,
      recruitAmountToday : 0,
      recruitAmountMonth : 0,
      recruitTotal : 0,
    },
    achivementType : 1,//1 个人 2门店
    chartImg : '',
    monthAchievement : {
      amount :0,
      monthAchievementObj :null
    },

  },

  //切换个人和门店
  onTapChangeAchivementData(e){
    let index = e.currentTarget.dataset.index;
    if(index == 1){
      this.setData({
        achivementType : index
      });
    }
    else if(index == 2){
      wx.showToast({
        title: '对不起，暂时还不能查看门店数据',
        icon : 'none'
      });
    }
  },

  //切换
  onTapChangeFilter(e){
    let index = e.currentTarget.dataset.index;
    this.data.filterBar.forEach(item => {
      item.isActive = false;
    });

    this.data.filterBar[index].isActive = true;
    this.data.current = this.data.filterBar[index].index;
    this.setData({
      filterBar: this.data.filterBar,
      current : this.data.current,
    });

    this.getGuidOrderPreview(this.data.current);
  },

  //获取头像
  getAvator() {
    wx.qy.getAvatar({
      success: res => {
        this.setData({
          avator: res.avatar
        });
      },
      fail: res => {
      }
    });
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    let currentUserInfo = wx.getStorageSync('guidBaseInfo');
    console.log('_baseUserInfo---',wx.getStorageSync('_baseUserInfo'))
    if (!currentUserInfo) { //未登录成功
      wx.redirectTo({
        url: '/shoppingGuid/page/pages/welcomGuider/welcomGuider',
      });
      return ;
    }

    // currentUserInfo = { member: { qiyeInfo: { name : '张三'}}}

    let userInfo = wx.getStorageSync('guidInfo');
    if (currentUserInfo.member) {
      if (!currentUserInfo.member.qiyeInfo.name) {
        currentUserInfo.member.name = userInfo.nickName;
      }
      else{
        currentUserInfo.member.name = currentUserInfo.member.qiyeInfo.name;
      }
    }

    this.setData({
      info: currentUserInfo
    });

    //获取导购业绩
    // this.getGuidAchievement();
    //获取导购业绩月统计
    this.getGuidAchievementMonth();
    //获取导购业界订单概览
    this.getGuidOrderPreview(this.data.current);
    //获取导购业绩日统计
    this.getGuidAchievementDay();
    //获取导购头像
    this.getAvator();
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    
  },

  //跳转到发布界面
  onTapToReleaseContent(){
    wx.navigateTo({
      url: '/shoppingGuid/page/pages/releaseContent/releaseContent',
    });
  },
  //跳转我的发布
  onTapToMyRelease(){
    wx.navigateTo({
      url: '/subPackage/page/pages/myRelease/myRelease',
    });
  },

  //跳转到我的会员列表
  onTapToMyMemberList(){
    wx.navigateTo({
      url: '/shoppingGuid/page/pages/myMemberList/myMemberList',
    });
  },

  //初始化barchart
  initBarChart(series){
    wx.showLoading({
      title: '加载中..',
    });
    let max = this.getMaxData(series) , disabled = false;
    if(max == 0){
      max = 0.1;
      disabled = true;
    }
    let self = this;
    let width = app.globalData.systemInfo.screenWidth - 30;
    let chart = new wxCharts({
      canvasId: 'columnCanvas',
      type: 'column',
      animation: true,
      categories: ['普通会员', '付费会员', '销售额'],
      series: series,
      legend : false,
      yAxis: {
        format: function (val) {
          return val;
        },
        min: 0,
        disabled : disabled,
        max: max
      },
      xAxis: {
        disableGrid: false,
        type: 'calibration'
      },
      extra: {
        column: {
          width: 20
        }
      },
      width: width,
      height: 250,
    });
    
    let systemInfo = wx.getSystemInfoSync();
    //监听wxchart渲染完成 把 canvas保存成图片 用图片展示
    chart.addEventListener('renderComplete', () => {
      wx.canvasToTempFilePath({
        width: systemInfo.windowWidth - 30,
        height : 300,
        canvasId: 'columnCanvas',
        success : res => {
          let url = res.tempFilePath;
          self.setData({
            chartImg : url
          });
        },
        fail : err => {
          console.log('err--',err)
        },
        complete : () => {
          wx.hideLoading();
        }
      });
    });
  },

  //获取最大值
  getMaxData(series){
    let arr = [];
    series.forEach(item => {
      arr = arr.concat(item.data);
    });
    let newArr = arr.sort();
    return newArr[arr.length - 1];
  },
  
  //导购招募会员概览
  getGuidMemberPreview(){
    wxService.post('/marketing/shoppingguide/achievement/memberPreview').then(res => {
      if (!res) return;
      let data = res.data.data;
      let series = [
        {
          name: '本月',
          color: 'rgba(0,145,255,0.2)',
          data: [data.memberRecruitAmountMonth, data.plusMemberRecruitAmountMonth, this.data.achievement.achievementMonth],
        },
        {
          name: '累计',
          color: 'rgba(0, 145, 255, 1)',
          data: [data.memberRecruitAmountTotal, data.plusMemberRecruitAmountTotal, this.data.achievement.achievementTotal],
        }
      ];

      this.initBarChart(series);
    });
    
  },
  //获取导购业绩月统计
  getGuidAchievementMonth(){
    wxService.post('/marketing/shoppingguide/achievement/month').then(res => {
      if (!res) return;
      this.data.achievement = res.data.data;
      this.setData({
        achievement: this.data.achievement
      });
      //获取会员统计
      this.getGuidMemberPreview();
    });
  },
  //导购业绩订单概览
  getGuidOrderPreview(type){
    wxService.post('/marketing/shoppingguide/achievement/orderPreview?type=' + type).then(res => {
      if (!res) return;
      this.data.currentOrderData = res.data.data;
      if(type == 1){
        //记录一下本月的业绩
        this.data.monthAchievement.monthAchievementObj = this.data.currentOrderData;
        let salesVolume = this.data.currentOrderData.salesVolume ? this.data.currentOrderData.salesVolume : 0;
        let refundVolume = this.data.currentOrderData.refundVolume ? this.data.currentOrderData.refundVolume : 0;
        this.data.monthAchievement.amount = parseFloat(salesVolume - refundVolume).toFixed(2);
        this.setData({
          monthAchievement: this.data.monthAchievement
        });
      }
      this.setData({
        currentOrderData: this.data.currentOrderData
      })
    });
  },
  //获取导购业绩日统计
  getGuidAchievementDay(){
    wxService.post('/marketing/shoppingguide/achievement/recruit').then(res => {
      if (!res) return;
      let obj = res.data.data ? res.data.data : null;
      if(obj){
        this.data.memberPreview.rank = obj.rank;
        this.data.memberPreview.recruitAmountMonth = obj.recruitAmountMonth;
        this.data.memberPreview.recruitAmountToday = obj.recruitAmountToday;
        this.data.memberPreview.recruitTotal = obj.recruitTotal;
        this.setData({
          memberPreview: this.data.memberPreview
        });
      }
      
    });
  },
})