// shoppingGuid/page/pages/releaseContent/releaseContent.js
const app = getApp()
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const envInfo = require('../../../../config/index').envInfo;

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    uploadImgs : [],
    videoUrl : '',
    article : '',
    headline : '',
    //选择标签
    showSelectTabModal : false,
    tagsId : '',
    tagName : '',
    proGoods : [],
    isRequesting : false,
    id : null,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.data.id = options.id ? options.id : null;
    //如果id存在 则是编辑
    if (this.data.id){
      wx.setNavigationBarTitle({
        title: '编辑种草',
      });
      this.getContentInfo();
    }
    wx.hideShareMenu();
  },
  
  //获取种草详情
  getContentInfo(){
    const { memberId } = wx.getStorageSync('_baseUserInfo')
    let params = {
      id: this.data.id,
      userId: memberId
    }

    wxService.post(`/merchant/contentMobileTerminal/terminalContentDetails`, params).then(res => {
      const { result, data } = res.data
      if (result == 0) {
        this.data.article = data.article;
        this.data.headline = data.headline;
        this.data.tagsId = data.tagsId;
        this.data.tagsName = data.tagsName;
        let sspList = data.sspList;
        sspList.forEach(item => {
          if(item.url){
            this.data.uploadImgs.push(item.url);
          }
          if(item.videoUrl){
            this.data.videoUrl = item.videoUrl;
          }
        });

        this.setData({
          uploadImgs: this.data.uploadImgs,
          videoUrl: this.data.videoUrl,
          article: this.data.article,
          headline: this.data.headline,
          //选择标签
          tagsId: this.data.tagsId,
          tagName: this.data.tagsName,
        });

        //获取商品数据去
        let productIds = data.productIds ? data.productIds  : [];
        if (productIds.length > 0){
          this.getProductsInfoByIds(productIds);
        }
      }
    });
  },

  //获取商品信息根据商品ids
  getProductsInfoByIds(productIds){
    wxService.post(`/sale/product/buyer/listPage?pageNo=1&pageSize=${productIds.length + 1}`, {
      productIds: productIds
    }).then(res => {
      const { result, data } = res.data;
      if (result == 0){
        let list = data.content ? data.content : [];
        list.forEach(item => {
          item.minSalePriceText = parseFloat(item.minSalePrice / 10 / 10).toFixed(2);
        });

        this.data.proGoods = list;
        this.setData({
          proGoods: this.data.proGoods
        });

      }
    })
  },

  //输入数据事件
  onInputChange(e){
    this.data.headline = e.detail.value;
  },

  //删除
  deleteImage(e){
    this.data.uploadImgs.splice(e.target.dataset.index,1);
    this.setData({
      uploadImgs: this.data.uploadImgs
    });
  },
  //输入
  bindWordLimit(e){
    var keyWord = e.detail.value
    this.throttle(this.queryData, null, 400, keyWord)
  },
  //
  queryData(e) {
    this.data.article = e // 此处打印出来的就是 用户输入的值
  },
  //节流器
  throttle(fn, context, delay, text){
    clearTimeout(fn.timeoutId)
    fn.timeoutId = setTimeout(function () {
      fn.call(context, text)
    }, delay)
  },

  //上传完video
  _uploadVideo(e){
    this.data.videoUrl = e.detail;
  },

  //删除video
  _deleteVideo(e){
    this.data.videoUrl = '';
  },

  //上传图片点击事件
  uploadImg(){
    let that = this;
    let pics = this.data.uploadImgs;
    var url = envInfo.ctx + '/merchant/upload/pic'
    wx.chooseImage({
      count: 5 - pics.length, // 最多可以选择的图片5张，
      sizeType: ['original', 'compressed'], // original 原图，compressed 压缩图，默认二者都有
      sourceType: ['album', 'camera'], // album 从相册选图，camera 使用相机，默认二者都有
      success: function (res) {
        var imgSrcs = res.tempFilePaths;
        //直接调用上传，上传完成之后才显示图片
        that.moreImgUpload({
          url: url,//这里是你图片上传的接口
          path: imgSrcs//这里是选取的图片的地址数组        
        });
      },
      fail: function () {
        // fail      
      },
      complete: function () {
        // complete      
      }
    })
  },
  //多图上传
  moreImgUpload(params){
    var that = this,
      i = params.i ? params.i : 0,//当前上传的哪张图片
      success = params.success ? params.success : 0,//上传成功的个数
      fail = params.fail ? params.fail : 0;//上传失败的个数
    wx.uploadFile({
      url: params.url,
      filePath: params.path[i],
      header: {
        'buyer-token': wx.getStorageSync('token')
      },
      name: 'imgs',//这里根据自己的实际情况改
      formData: null,//这里是上传图片时一起上传的数据
      success: (res) => {
        if (res.statusCode == 200) {
          var imgdata = JSON.parse(res.data);
          var img = imgdata.data[0];
          //图片上传成功，图片上传成功的变量+1
          success ++;
          that.data.uploadImgs.push(envInfo.imgCtx + img.url)
          that.setData({
            uploadImgs: that.data.uploadImgs
          })
        }
      },
      fail: (res) => {
        fail++;//图片上传失败，图片上传失败的变量+1
      },
      complete: (res) => {
        i++;
        //若图片还没有传完，则继续调用函数 
        if (i != params.path.length) {  
          params.i = i;
          params.success = success;
          params.fail = fail;
          that.moreImgUpload(params);
        }
      }
    });
  },
  
  //选择完标签
  //关联标签
  _selectTab(e) {
    this.setData({
      tagsId : e.detail.id,
      tagName: e.detail.name
    })
  },

  //点击去选择商品
  onTapToChooseProducts(){
    wx.setStorageSync('guiderReleaseProducts', this.data.proGoods);
    wx.navigateTo({
      url: '/shoppingGuid/page/pages/selectProductList/selectProductList',
    });
  },

  //选择标签
  onTapChooseTag(){
    this.setData({
      showSelectTabModal: true
    });
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    let chooseProducts = wx.getStorageSync('guiderReleaseProducts') ? wx.getStorageSync('guiderReleaseProducts') : [];
    if(chooseProducts.length > 0){
      this.setData({
        proGoods: chooseProducts,
      })
    }
    else{
      this.setData({
        proGoods: [],
      });
    }
  },
  //移除
  onTapRemove(e){
    let _this = this;
    let index = e.currentTarget.dataset.index;
    wx.showModal({
      title: '移除关联商品提示',
      content: '确认移除此关联商品？',
      showCancel: true,
      cancelText: '取消',
      confirmText: '移除',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          _this.data.proGoods.splice(index,1);
          _this.setData({
            proGoods: _this.data.proGoods
          });
        }
      }
    });
  },

  //确认发布
  onTapPublish(){
    // 防止用点击太快
    if(this.data.isRequesting){
      wx.showToast({
        title: '您点的太快啦~',
        icon : 'none'
      });
      return ;
    }

    if(!this.data.headline){
      wx.showToast({
        title: '请输入内容标题',
        icon : 'none'
      });
      return;
    }

    if (!this.data.article) {
      wx.showToast({
        title: '请设置内容信息',
        icon: 'none'
      });
      return;
    }

    //处理视频和图片
    let sspList = [];
    this.data.uploadImgs.forEach(item => {
      sspList.push({
        cover : 0,
        url: item
      });
    });
    //处理视频
    if(this.data.videoUrl){
      sspList.push({
        cover: 0,
        videoUrl: item
      });
    }

    if (sspList.length == 0){
      wx.showToast({
        title: '请上传至少一张图片/视频',
        icon: 'none'
      })
      return;
    }

    //找到第一个图片设为主图
    let isFirst = 0;
    sspList.forEach(item => {
      if (isFirst == 0 && item.url){
        item.cover = 1;
        isFirst ++ ;
      }
      else{
        item.cover = 0;
      }
    });

    //获取商品
    let checkedProducts = [];
    this.data.proGoods.forEach(item => {
      checkedProducts.push({
        commodityId: item.productId
      });
    });

    this.data.isRequesting = true;

    const { memberId } = wx.getStorageSync('_baseUserInfo')
    let param = {};
    param.article = this.data.article;
    param.headline = this.data.headline;
    param.sspList = sspList;
    param.stcList = checkedProducts;
    param.tagsId = this.data.tagsId;
    param.userId = memberId;
    param.id = this.data.id;

    wxService.post(`/merchant/contentMobileTerminal/contentSave`,param).then(res => {
      if(res){
        if(res.data.result == 0){
          wx.showToast({
            title: '发布成功',
          });

          wx.removeStorageSync('guiderReleaseProducts');

          wx.redirectTo({
            url: '/subPackage/page/pages/myRelease/myRelease',
          });
        }
      }
    }).catch(err => {
      this.data.isRequesting = false;
      wx.showToast({
        title: '发布失败，请稍后重试',
        icon : 'none'
      });
    });
  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {
    wx.removeStorageSync('guiderReleaseProducts');
  },
})