// shoppingGuid/page/pages/selectProductList/selectProductList.js
const app = getApp()
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const envInfo = require('../../../../config/index').envInfo;
const defaultGoodsImg = 'https://img3.bigaka.com/prd/3001/202003/20200331/30019aa78220-546f-41e0-8075-c2feb69e10b8.jpg';

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    productName : '',
    pageNo : 1,
    pageSize : 10,
    totalPages : 0,
    productList : [],
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.getProductList();
    wx.hideShareMenu();
  },

  //商品名称改变
  onProductNameChange(e){
    this.data.productName = e.detail.value;
  },
  //查询
  onTapFilter(){
    this.data.pageNo = 1;
    this.data.totalPages = 0;
    this.data.productList = [];
    this.getProductList();
  },
  //选择商品
  onTapChooseProduct(e){
    let index = e.currentTarget.dataset.index;
    this.data.productList[index].checked = !this.data.productList[index].checked;
    this.setData({
      productList: this.data.productList
    });
  },
  //获取商品列表
  getProductList(refresh){
    wxService.post(`/sale/product/listPage?pageNo=${this.data.pageNo}&pageSize=${this.data.pageSize}`, {
      productName: this.data.productName,
      productStatus : 2,
      showListUrls : true,
    }).then(res => {
      if(res){
        let list = res.data.data.content ? res.data.data.content : [];
        list.forEach(item => {
          item.checked = false;
          item.minSalePriceText = parseFloat(item.minSalePrice/10/10).toFixed(2);
          item.listUrls = item.listUrls ? item.listUrls : [];
          if(!utils.isVideo(item.indexUrl)){
            item.indexUrl = item.indexUrl ? item.indexUrl :defaultGoodsImg;
          }
          else{
            item.indexUrl = utils.getFirstImgUrl(item.listUrls);
            item.indexUrl = item.indexUrl ? item.indexUrl : defaultGoodsImg;
          }
        });

        this.data.productList = this.data.productList.concat(list);
        this.handlerChecked();
        this.data.totalPages = res.data.data.totalPages ? res.data.data.totalPages : 0;
        this.setData({
          productList: this.data.productList
        });
      }

      if (refresh){
        wx.stopPullDownRefresh();
        wx.showToast({
          title: '刷新成功!',
        });
      }
    });
  },
  
  //处理选中
  handlerChecked(){
    let checkedProduct = wx.getStorageSync('guiderReleaseProducts') ? wx.getStorageSync('guiderReleaseProducts') : [];
    if (checkedProduct.length != 0){
      checkedProduct.forEach(item => {
        let filter = this.data.productList.filter(c => c.productId == item.productId);
        if (filter.length > 0){
          filter.forEach(f => {
            f.checked = true;
          });
        }
      });
    }
  },

  //选择完成
  onTapChooseOk(e){
    //找到已选中的
    let checkedProducts = this.data.productList.filter(item => item.checked);
    if (checkedProducts.length == 0){
      wx.showToast({
        title: '请选择关联商品',
        icon : 'none',
      });
      return ;
    }

    wx.setStorageSync('guiderReleaseProducts', checkedProducts)

    wx.navigateBack({
      delta : 1
    });
  },

  /**
  * 页面相关事件处理函数--监听用户下拉动作
  */
  onPullDownRefresh: function () {
    this.data.pageNo = 1;
    this.data.totalPages = 0;
    this.data.productList = [];
    this.getProductList(true);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if(this.data.pageNo < this.data.totalPages){
      this.data.pageNo ++ ;
      this.getProductList();
    }
    else{
      if(this.data.pageNo > 1){
        wx.showToast({
          title: '没有更多商品了',
          icon : 'none'
        });
      }
    }
  },
});