// subPackage/page/pages/chooseStore/chooseStore.js
const wxService = require('../../../../utils/wxService')
const app = getApp()
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    latitude: 31.22114,
    longitude: 121.54409,
    pageNo : 1,
    totalPage :0,
    pageSize : 10,
    markers: [
      // {
      //   id: 1,
      //   latitude: 31.22114,
      //   longitude: 121.54409,
      //   name: 'T.I.T 创意园',
      //   iconPath: '/assets/imgs/location.png'
      // }
    ],
    storeList : [],
    isFrom : '',
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.data.isFrom = options.isFrom;
    this.setData({
      isFrom : this.data.isFrom
    });
    wx.hideShareMenu();
  },

  //去下单
  onTapToOrder(e){
    let item = e.currentTarget.dataset.item;
    if (this.data.isFrom == 'order'){
      wx.setStorageSync('choosedStoreInfo', item);
      wx.navigateBack({
        delta: 1
      });
    }
    else{
      let latitude = item.latitude;
      let longitude = item.longitude;
      wx.openLocation({
        latitude: latitude,
        longitude: longitude,
        name: item.fullname ? item.fullname : item.name,
        address: item.storeFullAddress
      });
    }
    
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {
    wx.showLoading({
      title: '数据加载中..',
    });

    this.renderMap();
    this.getMyLocation();
  },

  //获取我的位置
  getMyLocation(){
    let self = this;
    wx.getLocation({
      type: 'wgs84',
      success(res) {
        const latitude = res.latitude
        const longitude = res.longitude;
        self.setData({
          latitude: latitude,
          longitude: longitude,
        },() => {
          self.getStoreList();
        });
        
      }
    })
  },

  //渲染地图
  renderMap(){
    this.mapCtx = wx.createMapContext('myMap');
  },

  //获取附近的门店列表
  getStoreList(refresh){
    let pageNo = this.data.pageNo,
      pageSize = this.data.pageSize;
    let latitude = this.data.latitude,
      longitude = this.data.longitude;
    let url = `/sale/selfDelivery/store/findCloseStorePageByStoreIds?latitude=${latitude}&longitude=${longitude}&pageNo=${pageNo}&pageSize=${pageSize }`;
    wxService.post(url).then(res => {
      if(res){
        let list = res.data.data.content ? res.data.data.content : [];
        this.data.totalPage = res.data.data.totalPages;
        //处理marks
        let markers = list.map(item => {
          let addressArr = item.addressArea.split(',');
          addressArr.push(item.addressDetail);
          item.storeFullAddress = addressArr.join('');
          item.businessTimeText = item.businessTime ? item.businessTime.split(',').join('-') : '暂无营业时间';
          item.distanceText = item.distance ? parseFloat(item.distance).toFixed(2) : 0;
          return {
            id: item.id,
            latitude: item.latitude,
            longitude: item.longitude,
            name: item.name,
            iconPath: '/assets/imgs/location.png'
          }
        });
        
        this.data.storeList = this.data.storeList.concat(list);
        this.setData({
          storeList: this.data.storeList,
          markers: markers,
        });
      }

      wx.hideLoading();
      if (refresh){
        wx.stopPullDownRefresh();
        wx.showToast({
          title: '刷新成功',
        });
      }
    })
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },

  /**
  * 页面相关事件处理函数--监听用户下拉动作
  */
  onPullDownRefresh: function () {
    this.data.pageNo = 1;
    this.data.totalPage = 0;
    this.data.storeList = [];
    this.getStoreList(true);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onScrollViewReachBottom: function () {
    const { pageNo, pageSize, totalPage } = this.data
    if (pageNo < totalPage) {
      this.data.pageNo ++ ;
      this.getStoreList()
    }
    else{
      if (pageNo > 1){
        wx.showToast({
          title: '没有更多数据了',
          icon : 'none',
        });
      }
    }
  },

})