// subPackage/page/pages/selfPickUpOrderInfo/selfPickUpOrderInfo.js
const app = getApp();
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util');
var wxbarcode = require('../../../../codeUtils/index.js');

const orderStatusTextObj = {
  N : '待付款',
  P : '待自提',
  R : '已完成',
  C : '已取消',
  RE : '已退款'
}
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    id : null,
    orderInfo :{} 
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    this.data.id = options.id;
    this.setData({
      id: this.data.id
    },() => {
      this.generateBarCode();
    });
    
  },
  //onShow
  onShow(){

    this.getOrderInfo();
  },

  //获取订单详情
  getOrderInfo(){
    wx.showLoading({
      title: '加载中',
      mask: true
    });

    wxService.get(`/sale/trade/buyer/${this.data.id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          let skuVOList = data.skuVOList ? data.skuVOList : [];
          let sum = 0 ; 
          skuVOList.forEach(item => {
            item.refundCount = item.refundCount ? item.refundCount : 0;
            item.canRefundNum = (item.count - item.refundCount) >= 0 ? (item.count - item.refundCount) : 0;
            sum = sum + item.price * item.count;
          });
          data.orderStatusText = orderStatusTextObj[data.status];
          let store = data.store ? data.store : null;
          data.storeAddress = '暂无地址';
          data.latitude = '';
          data.longitude = '';
          if(store){
            let addressArr = store.addressArea ? store.addressArea.split(',') : [];
            addressArr.push(store.addressDetail);
            data.storeAddress = addressArr.join('');
            data.latitude = store.latitude;
            data.longitude = store.longitude;
          }
          
          //能不能申请退单通过支付时间制定后多少天可以申请退款
          if(data.status == 'C' || data.status == 'N' || data.status == 'RE'){
            data.orderCanRefund = false;
          }
          else{
            let diffObj = utils.getDateDiff(data.payTime);
            if (diffObj.days <= this.data.canRefundDaysAfterDelivery){
              let filter = skuVOList.filter(c => c.canRefundNum > 0);
              if (filter.length > 0){
                data.orderCanRefund = true;
              }
              else{
                data.orderCanRefund = false;
              }
            }
            else{
              data.orderCanRefund = false;
            }
          }
          
          
          //处理能不能退款
          let canApplyRefund = true;
          let filter = skuVOList.filter(c => c.canRefundNum > 0);
          if (filter.length > 0){
            canApplyRefund = true;
          }
          else{
            canApplyRefund = false;
          }

          this.data.totalGoodsPrice = parseFloat(sum).toFixed(2);
          this.data.orderInfo = data;
          this.setData({
            orderInfo: this.data.orderInfo,
            totalGoodsPrice: this.data.totalGoodsPrice,
            mergedAmount: data.mergedAmount || 0,
            canApplyRefund: canApplyRefund
          });
        }
      }
    })
  },
  //生成条形码
  generateBarCode() {
    let id = this.data.id + '_1';
    wxbarcode.barcode('barcode', id, 640, 140);
    setTimeout(() => {
      wxbarcode.barcode('barcode', id, 640, 140);
    }, 200);
  },
  canvasIdErrorCallback(e) {
    console.log('code-me', e.detail.errMsg)
  },
  copy(e) {
    wx.setClipboardData({
      //准备复制的数据
      data: e.currentTarget.dataset.content,
      success: function (res) {
        wx.showToast({
          title: '复制成功',
          icon: 'none'
        });
      }
    });
  },
    //立即支付
  onTapPayNow(e){
    let _this = this;
    let url = `/sale/trade/buyer/wxprepay/${this.data.id}`
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wxService.post(`${url}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let amount = data.amount || 0
          wx.hideLoading()
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // 支付成功页面
              wx.showToast({
                title: '支付成功!',
              })
              _this.getOrderInfo();
            },
            fail(res) {
              wx.hideLoading()
              wx.showToast({
                title: '支付已取消',
                icon : 'none'
              });
            }
          }, data))
        }
      }
    });
  },
  //取消订单
  onTapCancelOrder(){
    let _this = this;
    wx.showModal({
      title: '订单取消提示',
      content: '确认取消此订单？',
      showCancel: true,
      cancelText: '再想想',
      confirmText: '取消订单',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          wx.showLoading({
            title: '订单取消中..',
            mask: true
          });

          wxService.post(`/sale/trade/buyer/cancel/${_this.data.id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `取消成功!`,
                  icon: 'none'
                })
                setTimeout(() => {
                  _this.getOrderInfo();
                }, 200)
              } else {
                wx.showToast({
                  title: `取消失败!`,
                  icon: 'none'
                })
              }
            }
          })
        }
      }
    });
  },
  //申请退款
  handelRequestRefund(e) {
    
    const id = this.data.id;
    const detail = this.data.orderInfo;
    detail.id = this.data.id;
    let copyOrderInfo = JSON.parse(JSON.stringify(detail));
    //过滤掉已经退货完的商品
    copyOrderInfo.skuVOList = copyOrderInfo.skuVOList.filter(item => item.canRefundNum > 0);
    //更新可退货数量
    copyOrderInfo.skuVOList.forEach(item => {
      item.totalCount = item.count;
      item.count = item.canRefundNum;
    });

    
    delete copyOrderInfo.store;
    delete copyOrderInfo.storeAddress;
    delete copyOrderInfo.storeCode;
    delete copyOrderInfo.storeId;
    delete copyOrderInfo.storeName;
    delete copyOrderInfo.latitude;
    delete copyOrderInfo.longitude;
    delete copyOrderInfo.orderStore;

    let params = JSON.stringify(copyOrderInfo);
    // 退款申请
    wxService.router(`/pages/refund/refund`).search({params})
  },
  //确认收货
  handelConfirmReceipt(e) { 
    const id  = this.data.id;
    let _this = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wxService.post(`/sale/trade/seller/selfconfirm/${id}`).then(res => {
      wx.hideLoading()
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            _this.getOrderInfo();
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
        }
      }
    })
  },
  //导航
  onTapGuid(){
    let latitude = this.data.orderInfo.latitude;
    let longitude = this.data.orderInfo.longitude;
    wx.openLocation({
      latitude: latitude,
      longitude: longitude,
      name : this.data.orderInfo.storeName,
      address : this.data.orderInfo.storeAddress
    });
  }
})