// subPackage/page/pages/selfPickUpOrderList/selfPickUpOrderList.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const orderStatusTextObj = {
  N : '待付款',
  P : '待自提',
  R : '已完成',
  C : '已取消',
  RE : '已退款'
}
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    pageNo : 1,
    pageSize : 10,
    totalPages : 0,
    orderList : [],
    hasMoreData : true,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();

    this.initOrderList();
  },

  //获取订单列表
  initOrderList(refresh) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = { status: '',orderType:4 }
    let pageNo = this.data.pageNo,
    pageSize = this.data.pageSize;

    wxService.post(`/sale/trade/buyer/history?pageNum=${pageNo}&pageSize=${pageSize}`, params).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          
          let list  = data ? data : [];
          if(list.length == 0 && this.data.pageNo > 1){
            this.data.hasMoreData = false;
          }
          else{
            this.data.hasMoreData = true;
          }

          list.forEach(item => {
            item.orderStatusText = orderStatusTextObj[item.status];
          });

          this.data.orderList = this.data.orderList.concat(list);
          this.setData({
            hasMoreData : this.data.hasMoreData,
            orderList : this.data.orderList
          });
        }
      }

      if(refresh){
        wx.stopPullDownRefresh();
        wx.showToast({
          title: '刷新成功',
        });
      }
    })
  },

  //跳转到订单详情
  onTapToOrderInfo(e){
    let item = e.currentTarget.dataset.item;
    wx.navigateTo({
      url: '/subPackage/page/pages/selfPickUpOrderInfo/selfPickUpOrderInfo?id=' + item.id,
    });
  },
  //立即支付
  onTapPayNow(e){
    let _this = this;
    let item = e.currentTarget.dataset.item;
    let url = `/sale/trade/buyer/wxprepay/${item.id}`
    wx.showLoading({
      title: '加载中',
      mask: true
    })

    wxService.post(`${url}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let amount = data.amount || 0
          wx.hideLoading()
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // 支付成功页面
              wx.showToast({
                title: '支付成功!',
              })
              _this.initOrderList();
            },
            fail(res) {
              wx.hideLoading()
              wx.showToast({
                title: '支付已取消',
                icon : 'none'
              });
            }
          }, data))
        }
      }
    });
  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    this.data.pageNo = 1;
    this.data.hasMoreData = true;
    this.data.orderList = [];
    this.initOrderList(true);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if(this.data.hasMoreData){
      this.data.pageNo ++;
      this.initOrderList();
    }
  },
})