// share/share.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const envInfo = require('../../../../config/index').envInfo
const app = getApp()
const deviceWidth = app.globalData.systemInfo.windowWidth;
const isIPX = app.globalData.systemInfo.model == 'iPhone X';
let deviceHeight = app.globalData.systemInfo.windowHeight;
const ratio = deviceWidth / deviceHeight;
// 单位转换
const rpx2px = rpx => deviceWidth / 750 * rpx

/**
 * 设置文本行数，超出省略
 * @param {object} ctx canvas实例
 * @param {string} text 文本数据
 * @param {number} lineNum 行数
 * @param {number} width 文字宽度最宽默认 620rpx
 * 返回 由每一行组成的数组
 */
const setTextLine = (ctx, text, lineNum = 1, width = 610) => {
  const str_arr = String(text).split('')
  width = rpx2px(width)
  let temp = ''
  // 分行
  let row_arr = str_arr.reduce((arr, word) => {
    const w = ctx.measureText(temp).width
    if (w < width) {
      temp += word;
    } else {
      arr.push(temp)
      temp = word
    }
    return arr
  }, [])
  row_arr.push(temp)
  temp = ''

  // 判断需要的行数
  row_arr = row_arr.slice(0, lineNum)
  if (row_arr.length > 1) {
    // 最后一行超出则省略号
    row_arr[row_arr.length - 1].split().every(v => {
      temp += v
      if (ctx.measureText(temp).width > (width - 20)) {
        temp += '...'
        return false
      }
      return true
    })
    row_arr.splice(row_arr.length - 1, 1, temp)
  }

  return row_arr
}

//获取图片信息
function getImageInfo(url) {
  if (url) {
    return new Promise((resolve, reject) => {
      wx.getImageInfo({
        src: url,
        success: resolve,
        fail: reject,
      })
    })
  }
}

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    shareLogo: envInfo.shareLogo,
    shareTitle: envInfo.shareTitle,
    productImg: '',
    qrcodeImg: '',
    product: {
      productName: '',
      price: '',
      productId: '',
      type: '',
    },
    tempShareLogo: '',
    username: '',
    height: '1000rpx',
    canvasTempFileUrl: '',
    btnIsDisabled: true,
    isInput: false,
    inputText: '',
    sourceText: '',
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let shareInfo = wx.getStorageSync('shareInfo') ? wx.getStorageSync('shareInfo') : null;
    this.getCurrentUserName();
    wx.hideShareMenu();
    if (shareInfo) {
      this.data.productImg = shareInfo.productImg;
      this.data.qrcodeImg = shareInfo.qrcodeImg;
      this.data.product.productName = shareInfo.productName;
      this.data.sourceText = shareInfo.productName;
      this.data.product.price = shareInfo.minSalePrice ? shareInfo.minSalePrice : null;
      this.data.product.productId = shareInfo.productId;
      this.data.product.type = shareInfo.type;
      this.downloadProductImg();
    }
  },

  //頁面销毁
  onUnload(){
    wx.removeStorageSync('shareInfo')
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },
  //获取登录用户系信息
  getCurrentUserName() {
    let userInfo = wx.getStorageSync('_baseUserInfo') ? wx.getStorageSync('_baseUserInfo') : null;
    if (!userInfo) {
      this.data.username = '匿名';
    }
    else {
      this.data.username = userInfo.member.name ? userInfo.member.name : (userInfo.member.memberWeixin ? userInfo.member.memberWeixin.nickname : '匿名');
    }

    this.setData({
      username: this.data.username
    });
  },
  //下载商品图
  downloadProductImg() {
    wx.showLoading({
      title: '生成中...',
      mask: true,
    });
    var that = this;
    let productImage = this.data.productImg;
    wx.downloadFile({
      url: productImage,
      success: function (res) {
        if (res.statusCode === 200) {
          var productSrc = res.tempFilePath;
          that.calculateImg(productSrc, function (data) {
            that.getQrCode(productSrc, data);
          });
        }
        else {
          wx.showToast({
            title: '产品图片下载失败！',
            icon: 'none',
            duration: 2000,
            success: function () {
              var productSrc = "";
              that.getQrCode(productSrc);
            }
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '产品图片下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })

  },
  //下载二维码图
  getQrCode(productSrc, productImgInfo = "") {
    var that = this;
    let qrcodeImg = this.data.qrcodeImg;
    wx.downloadFile({
      url: qrcodeImg,
      success: function (res) {
        if (res.statusCode === 200) {
          var qrcodeUrl = res.tempFilePath;
          that.downloadShareLogo(function () {
            that.sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo);
          });
        }
        else {
          wx.showToast({
            title: '二维码下载失败！',
            icon: 'none',
            duration: 2000,
            success: function () {
              var qrcodeUrl = "";
              that.downloadShareLogo(function () {
                that.sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo);
              });
            }
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '二维码下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })
  },
  //下载商户logo
  downloadShareLogo(cb) {
    let self = this;
    let shareLogo = self.data.shareLogo;
    wx.downloadFile({
      url: shareLogo,
      success: function (res) {
        wx.hideLoading();
        if (res.statusCode === 200) {
          var codeSrc = res.tempFilePath;
          self.data.tempShareLogo = codeSrc;
        }
        else {
          self.data.tempShareLogo = '';
        }

        cb && cb();
      },
      fail: function (res) {
        wx.hideLoading();
        wx.showToast({
          title: '二维码下载失败！',
          icon: 'none',
          duration: 2000,
        })
      }
    })
  },
  //计算图片
  calculateImg(src, cb) {
    var that = this;
    wx.getImageInfo({
      src: src,
      success(res) {
        cb(res);
      }
    })
  },
  //图片自适应大小
  getImageSizeByAspectFit(imageSize, w, h) {
    var scale, imageHeight, imageWidth;
    scale = imageSize.width / imageSize.height;
    imageHeight = w / scale;
    if (imageHeight > h) {
      imageWidth = h * scale;
      imageSize.width = imageWidth;
      imageSize.height = h;
    } else {
      imageSize.width = w;
      imageSize.height = imageHeight;
    }
    // console.log('改变imageSize', imageSize.width, imageSize.height)
    return imageSize;
  },
  //生成canvas
  sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo) {
    const self = this;

    const ctx = wx.createCanvasContext('myCanvas', this)
    const canvasWidth = rpx2px(281 * 2)
    const canvasHeight = rpx2px(500 * 2)
    // 绘制背景，填充满整个canvas画布
    ctx.setFillStyle('#fff')
    ctx.fillRect(0, 0, canvasWidth, canvasHeight)

    //商品图片
    const proUrlWidth = rpx2px(240 * 2)
    const proUrlHeight = rpx2px(240 * 2)
    const proUrlX = rpx2px(15 * 2)
    const proUrlY = rpx2px(108 * 2)
    ctx.drawImage(productSrc, proUrlX, proUrlY, proUrlWidth, proUrlHeight)
    //二维码
    const proQrWidth = rpx2px(85 * 2)
    const proQrHeight = rpx2px(85 * 2)
    const proQrX = rpx2px(175 * 2)
    const proQrY = rpx2px(370 * 2)
    ctx.drawImage(qrcodeUrl, proQrX, proQrY, proQrWidth, proQrHeight)
    ctx.setFillStyle('#999')
    ctx.setFontSize(rpx2px(11 * 2))
    ctx.fillText('长按识别小程序码', rpx2px(170 * 2), rpx2px(470 * 2))
    //顶部显示名称
    const nickNameTop = rpx2px(30 * 2)
    ctx.setFillStyle('#999')  // 昵称
    ctx.setFontSize(rpx2px(13 * 2)) // 文字字号
    ctx.setTextAlign('left')
    ctx.fillText(self.data.username, rpx2px(66 * 2), rpx2px(65 * 2))
    ctx.setFillStyle('#000')
    ctx.fillText('我发现的精美好物，分享给你哟~', rpx2px(66 * 2), rpx2px(85 * 2))
    
    
    //商品文字
    self.data.product.productName = self.data.product.productName ? self.data.product.productName : '暂无商品名称信息~';
    ctx.setTextAlign('left')    // 
    ctx.setFillStyle('#333333')  // 文字颜色：黑色
    ctx.setFontSize(rpx2px(13 * 2))         // 文字字号
    const proNameX = rpx2px(15 * 2)
    const proNameFY = rpx2px(427 * 2)
    const proCodeX = rpx2px(20 * 2)
    const proCodeY = rpx2px(470 * 2)
    const proNameMW = rpx2px(240 * 2)
    // let proNameShow = self.data.product.productName;
    let textArr = setTextLine(ctx, self.data.product.productName, 3, rpx2px(240 * 2));
    // ctx.fillText(textArr[0], proNameX, proNameFY, proNameMW)
    // console.log(textArr)
    textArr.forEach((item, index) => {
      ctx.fillText(item, proNameX, proNameFY + rpx2px(18 * 2) * index, proNameMW)
    });

    //价格
    if (self.data.product.price){
      const priceActX = rpx2px(345 * 2)
      ctx.setFillStyle('#cb3c3c')  // 文字颜色
      ctx.setFontSize(rpx2px(15 * 2))
      ctx.fillText('￥', rpx2px(15 * 2), priceActX + rpx2px(50 * 2))
      ctx.setFontSize(rpx2px(20 * 2)) // 文字字号
      ctx.setTextAlign('left')
      let proActPrice = parseFloat(self.data.product.price / 10 / 10).toFixed(2);
      if (proActPrice && proActPrice.indexOf('-') > 0) {
        proActPrice = proActPrice.substring(0, proActPrice.indexOf('-'))
      }

      ctx.fillText(proActPrice, rpx2px(30 * 2), priceActX + rpx2px(50 * 2))
    } 

    //商户logo
    if (self.data.tempShareLogo) {
      // const circleX = rpx2px(40 * 2)
      // const circleY = rpx2px(55 * 2)
      // const circleR = rpx2px(25 * 2)
      // const circleSAngle = rpx2px(0 * 2)
      // ctx.arc(circleX, circleY, circleR, circleSAngle, Math.PI * 2, false)
      // ctx.clip()
      const avatarWidth = rpx2px(50 * 2)
      const avatarHeight = rpx2px(50 * 2)
      const avatarTop = rpx2px(70 * 2)
      ctx.drawImage(self.data.tempShareLogo, rpx2px(38 * 2) - avatarWidth / 2, avatarTop - avatarHeight / 2, avatarWidth, avatarHeight)
    }

    ctx.stroke()
    ctx.draw(false , () => {
      wx.canvasToTempFilePath({
        canvasId: 'myCanvas',
        quality: 1,
        success: result => {
          self.data.btnIsDisabled = false;
          self.data.canvasTempFileUrl = result.tempFilePath;
          self.setData({
            canvasTempFileUrl: self.data.canvasTempFileUrl,
            btnIsDisabled: self.data.btnIsDisabled
          });
        }
      }, self);
    });

    wx.hideLoading();
  },
  //按钮保存海报
  onTapSaveImg() {
    var that = this;
    if(this.data.btnIsDisabled){
      wx.showToast({
        title: '请等待海报生成完成',
        icon : 'none'
      });
      return ;
    }

    wx.showLoading({
      title: '正在保存',
      mask: true,
    });

    setTimeout(function () {
      var tempFilePath = that.data.canvasTempFileUrl;
      wx.saveImageToPhotosAlbum({
        filePath: tempFilePath,
        success(res) {
          wx.hideLoading();
          wx.showModal({
            content: '图片已保存到相册，赶紧晒一下吧~',
            showCancel: false,
            confirmText: '好的',
            confirmColor: '#333',
            success: function (res) {
              if (res.confirm) { }
            },
            fail: function (res) {
              console.log(res)
            }
          })
        },
        fail: function (res) {
          wx.hideLoading();
          wx.showToast({
            title: res.errMsg,
            icon: 'none',
            duration: 2000
          })
        }
      })
    }, 1000);
  },
  //编辑文案
  onTapEditShareContent() {
    this.data.isInput = true;
    this.setData({
      inputText: this.data.product.productName,
      isInput: this.data.isInput
    });
  },
  //输入
  onShareTextInput(e) {
    let value = e.detail.value;
    this.data.inputText = value;
  },
  //取消
  onTapCancal() {
    this.setData({
      isInput: false
    });
  },
  //确认
  onTapSure() {
    if (!this.data.inputText) {
      wx.showToast({
        title: '请输入分享文案',
        icon: 'none'
      });
      return;
    }

    this.data.product.productName = this.data.inputText;

    //重新绘制一下图
    this.setData({
      isInput: false
    }, () => {
      this.downloadProductImg();
    });
  },
  //重置文案
  onTapReset() {
    this.data.product.productName = this.data.sourceText;
    //重新绘制一下图
    this.setData({
      isInput: false
    }, () => {
      this.downloadProductImg();
    });
  }
});