// subPackage/page/pages/selfPickUpOrderInfo/selfPickUpOrderInfo.js
const app = getApp();
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util');
var wxbarcode = require('../../../../codeUtils/index.js');

const orderStatusTextObj = {
  N: '待付款',
  P: '待自提',
  R: '已完成',
  C: '已取消',
  RE: '已退款'
}
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    id: null,
    orderInfo: {}
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    this.data.id = options.id;
    this.getOrderInfo();
  },
  //获取订单详情
  getOrderInfo() {
    wx.showLoading({
      title: '加载中',
      mask: true
    });

    wxService.get(`/sale/trade/buyer/${this.data.id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          let skuVOList = data.skuVOList ? data.skuVOList : [];
          let sum = 0;
          skuVOList.forEach(item => {
            item.refundCount = item.refundCount ? item.refundCount : 0;
            item.canRefundNum = (item.count - item.refundCount) >= 0 ? (item.count - item.refundCount) : 0;
            sum = sum + item.price * item.count;
          });
          data.orderStatusText = orderStatusTextObj[data.status];
          let store = data.store ? data.store : null;
          data.storeAddress = '暂无地址';
          data.latitude = '';
          data.longitude = '';
          if (store) {
            let addressArr = store.addressArea ? store.addressArea.split(',') : [];
            addressArr.push(store.addressDetail);
            data.storeAddress = addressArr.join('');
            data.latitude = store.latitude;
            data.longitude = store.longitude;
          }

          //处理能不能退款
          let canApplyRefund = true;
          let filter = skuVOList.filter(c => c.canRefundNum > 0);
          if (filter.length > 0) {
            canApplyRefund = true;
          }
          else {
            canApplyRefund = false;
          }

          this.data.totalGoodsPrice = parseFloat(sum).toFixed(2);
          this.data.orderInfo = data;
          this.setData({
            orderInfo: this.data.orderInfo,
            totalGoodsPrice: this.data.totalGoodsPrice,
            mergedAmount: data.mergedAmount || 0,
            canApplyRefund: canApplyRefund
          });
        }
      }
    })
  },

  //确认用收货
  onTapSureGetGoods(){
    let _this = this;
    wx.showModal({
      title: '自提收货确认',
      content: '请确认用户已经收货切用户已同意收货',
      confirmText: '确认收货',
      confirmColor: '#cb3c3c',
      showCancel: false,
      success(confirm) {
        if (confirm.confirm) {
          _this.sureDeliveryGoods(_this.data.id);
        }
      },
    })
  },

  //调用接口
  sureDeliveryGoods(id){
    wx.showLoading({
      title: '请求中..',
    });
    wxService.post(`/sale/trade/seller/selfconfirm/${id}`).then(res => {
      wx.hideLoading()
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.showToast({
            title: `已确认收货`,
          });
          setTimeout(() => {
            this.getOrderInfo();
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
        }
      }
    })
  }
  
})